# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

# NOTE! THIS FILE IS AUTOMATICALLY GENERATED AND WILL BE OVERWRITTEN!
#
# IF YOU WANT TO MODIFY THIS FILE, YOU SHOULD MODIFY THE TEMPLATE
# `get_provider_info_TEMPLATE.py.jinja2` IN the `dev/breeze/src/airflow_breeze/templates` DIRECTORY


def get_provider_info():
    return {
        "package-name": "apache-airflow-providers-qdrant",
        "name": "Qdrant",
        "description": "`Qdrant <https://qdrant.tech/documentation>`__\n",
        "integrations": [
            {
                "integration-name": "Qdrant",
                "external-doc-url": "https://qdrant.tech/documentation",
                "logo": "/docs/integration-logos/Qdrant.svg",
                "how-to-guide": ["/docs/apache-airflow-providers-qdrant/operators/qdrant.rst"],
                "tags": ["software"],
            }
        ],
        "hooks": [
            {"integration-name": "Qdrant", "python-modules": ["airflow.providers.qdrant.hooks.qdrant"]}
        ],
        "connection-types": [
            {
                "hook-class-name": "airflow.providers.qdrant.hooks.qdrant.QdrantHook",
                "connection-type": "qdrant",
                "conn-fields": {
                    "url": {
                        "label": "URL",
                        "schema": {
                            "type": ["string", "null"],
                            "description": "Optional. Qualified URL of the Qdrant instance. Example: https://xyz-example.eu-central.aws.cloud.qdrant.io:6333",
                        },
                    },
                    "grpc_port": {
                        "label": "GRPC Port",
                        "schema": {
                            "type": ["integer", "null"],
                            "default": 6334,
                            "description": "Optional. Port of the gRPC interface.",
                        },
                    },
                    "prefer_gprc": {
                        "label": "Prefer GRPC",
                        "schema": {
                            "type": ["boolean", "null"],
                            "default": False,
                            "description": "Optional. Whether to use gPRC interface whenever possible in custom methods.",
                        },
                    },
                    "https": {
                        "label": "HTTPS",
                        "schema": {
                            "type": ["boolean", "null"],
                            "description": "Optional. Whether to use HTTPS(SSL) protocol.",
                        },
                    },
                    "prefix": {
                        "label": "Prefix",
                        "schema": {
                            "type": ["string", "null"],
                            "description": "Optional. Prefix to the REST URL path. Example: service/v1 will result in http://localhost:6333/service/v1/{qdrant-endpoint} for REST API.",
                        },
                    },
                },
                "ui-field-behaviour": {
                    "hidden-fields": ["schema", "login", "extra"],
                    "relabeling": {"password": "API Key"},
                },
            }
        ],
        "operators": [
            {"integration-name": "Qdrant", "python-modules": ["airflow.providers.qdrant.operators.qdrant"]}
        ],
    }
